@@ -40,10 +40,10 @@ public:
     kpEffectEmbossCommand (int strength,
                            bool actOnSelection,
                            kpCommandEnvironment *environ);
-    virtual ~kpEffectEmbossCommand ();
+    ~kpEffectEmbossCommand () override;
 
 protected:
-    kpImage applyEffect (const kpImage &image) Q_DECL_OVERRIDE;
+    kpImage applyEffect (const kpImage &image) override;
 
 protected:
     int m_strength;
