@@ -40,12 +40,12 @@ public:
     kpToolTextChangeStyleCommand (const QString &name,
         const kpTextStyle &newTextStyle, const kpTextStyle &oldTextStyle,
         kpCommandEnvironment *environ);
-    virtual ~kpToolTextChangeStyleCommand ();
+    ~kpToolTextChangeStyleCommand () override;
 
-    kpCommandSize::SizeType size () const Q_DECL_OVERRIDE;
+    kpCommandSize::SizeType size () const override;
 
-    void execute () Q_DECL_OVERRIDE;
-    void unexecute () Q_DECL_OVERRIDE;
+    void execute () override;
+    void unexecute () override;
 
 protected:
     kpTextStyle m_newTextStyle, m_oldTextStyle;
